@@ -6,58 +6,8 @@ use XML::Sablotron;
 
 use vars qw/@ISA $VERSION/;
 
-@ISA = qw/XML::Schematron/;
-$VERSION = $XML::Schematron::VERSION;
-
-sub tests_to_xsl {
-    my $self = shift;
-    my $template;
-    my $mode = 'M0';
-    my $ns = qq{xmlns:xsl="http://www.w3.org/1999/XSL/Transform"};
-
-    $template = qq{<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
-    <xsl:stylesheet $ns version="1.0">
-    <xsl:output $ns method="text"/>
-    <xsl:template $ns match="/">
-    <xsl:apply-templates $ns select="/" mode="$mode"/>};
-
-    
-    my $last_context_path = '';
-    my $priority = 4000;
-    foreach my $testref (@{$self->{tests}}) {
-        my ($test, $context_path, $message, $test_type, $pattern) = @{$testref};
-        $context_path =~ s/"/'/g if $context_path =~ /"/g;
-        $test =~ s/</&lt;/g;
-        $test =~ s/>/&gt;/g;
-        $message =~ s/\n//g;
-        $message .= "\n";
-
-        if ($context_path ne $last_context_path) {
-             $template .= qq{\n<xsl:apply-templates $ns mode="$mode"/>\n} unless $priority == 4000;
-             $template .= qq{</xsl:template>\n<xsl:template $ns match="$context_path" priority="$priority" mode="$mode">};
-             $priority--;
-        }
-        
-        if ($test_type eq 'assert') {
-            $template .= qq{<xsl:choose $ns>
-                            <xsl:when $ns test="$test"/>
-                            <xsl:otherwise $ns>In pattern $pattern: $message</xsl:otherwise>
-                            </xsl:choose>};
-        }
-        else {
-            $template .= qq{<xsl:if $ns test="$test">In pattern $pattern: $message</xsl:if>};
-        }
-        $last_context_path = $context_path;
-    }
-
-    
-    $template .= qq{<xsl:apply-templates $ns mode="$mode"/>\n</xsl:template>\n
-                    <xsl:template xmlns:xsl="http://www.w3.org/1999/XSL/Transform" match="text()" priority="-1" mode="M0"/>
-                    </xsl:stylesheet>};
-    
-    #print "$template\n";
-    return $template;
-}
+@ISA = qw/XML::SchematronXSLTProcessor/;
+$VERSION = '0.93';
 
 sub verify {
     my $self = shift;    
@@ -97,12 +47,6 @@ sub verify {
    return $ret_string;
 }
 
-sub dump_xsl {
-    my $self = shift;
-    my $stylesheet = $self->tests_to_xsl;;
-    return $stylesheet; 
-}
-
 1;
 __END__
 # Below is the stub of documentation for your module. You better edit it!
